exitnaver
=========

exitnaver exports your Naver blog in Markdown format.

Installation
------------

It is available on PyPI__, so you can install it using ``pip``.

.. code-block:: console

    $ pip install exitnaver

__ https://pypi.python.org/pypi/exitnaver

Usage
-----

.. code-block:: console

    $ exitnaver username

Changelog
---------

Logging changes between PyPI exitnaver releases.

Version 0.3.0
`````````````

Python 3 support, thanks to `@youngminz <https://github.com/youngminz>`_!

Version 0.2.2
`````````````

Bugfix release. Fixed encoding issue in Windows, thanks to `@lqez <https://github.com/lqez>`_!

Released on July 11, 2015.

Version 0.2.1
`````````````

Bugfix release. Thanks to `@lqez <https://github.com/lqez>`_! Released on July 10, 2015.

Version 0.2
```````````

Output optimization and a number of bug fixes.

Version 0.1
```````````

Initial public release.
